@@ -99,6 +99,8 @@ public class ResourceIcon implements Icon {
         FITS = makeIcon( "fits1.png" ),
         COPY = makeIcon( "Copy24.png" ),
         REDO = makeIcon( "Redo24.png" ),
+        PAUSE = makeIcon( "Pause24.png" ),
+        SCROLL = makeIcon( "History24.png" ),
         ADD = makeIcon( "Plus1.png" ),
         SUBTRACT = makeIcon( "Minus1.png" ),
         DELETE = makeIcon( "trash2.png" ),
@@ -264,6 +266,7 @@ public class ResourceIcon implements Icon {
         PLOT_QUAD = makeIcon( "quadplot.png" ),
         PLOT_HISTO = makeIcon( "histoplot.png" ),
         PLOT_AREA = makeIcon( "areaplot.png" ),
+        PLOT_VECTOR = makeIcon( "vectorplot.png" ),
         PLOT2_PLANE = makeIcon( "plot2plane.png" ),
         PLOT2_SKY = makeIcon( "plot2sky.png" ),
         PLOT2_CUBE = makeIcon( "plot2cube.png" ),
@@ -726,6 +729,11 @@ public class ResourceIcon implements Icon {
         putMap( nameMap, "ADD_PLOT_QUAD", toAddIcon( PLOT_QUAD ) );
         putMap( nameMap, "ADD_PLOT_AREA", toAddIcon( PLOT_AREA ) );
         putMap( nameMap, "ADD_PLOT_HISTO", toAddIcon( PLOT_HISTO ) );
+        putMap( nameMap, "ADD_PLOT_HEALPIX", toAddIcon( TTRI.PLOT_HEALPIX ) );
+        putMap( nameMap, "ADD_PLOT_SPECTRO", toAddIcon( TTRI.PLOT_SPECTRO ) );
+        putMap( nameMap, "ADD_PLOT_XYARRAY", toAddIcon( PLOT_VECTOR ) );
+        putMap( nameMap, "ADD_PLOT_FUNCTION", toAddIcon( TTRI.PLOT_FUNCTION ) );
+        putMap( nameMap, "ADD_PLOT_SKYGRID", toAddIcon( TTRI.PLOT_SKYGRID ) );
         putMap( nameMap, "ADD_FORM_MARK", toAddIcon( TTRI.FORM_MARK ) );
         putMap( nameMap, "ADD_FORM_SIZE", toAddIcon( TTRI.FORM_SIZE ) );
         putMap( nameMap, "ADD_FORM_SIZEXY", toAddIcon( TTRI.FORM_SIZEXY ) );
